%**************************************************************************
% Filename   : addMaskToMovie.m
% Description: add to each frame the track corresponfing to the movement of
%              the subject in the previous specified k frames.
% Authors    : Marco Branca, Lorenzo Camerini
%**************************************************************************
frameWithKTrack = frames;

colorWaitbar(0, barHandler, 'Adding track to the movie: please wait...');
numFrames = length(frames);

for i = 2:numFrames-1
    track = mask(:,:,i);
    
    if i <= k 
        first = 1;        
    else
        first = i-k;
    end
    
    for j = first:samplingRate:i
        if rand >= flickeringFactor
            track = track + mask(:,:,j);
        end
    end
    
    %compute the matrix that, added to the last frame, returns the white image
    trackMatrix = cast(255*ones(size(frameWithKTrack(i).cdata)),'uint8') - frameWithKTrack(i).cdata;

    %convert the track matrix in a RGB variable
    trackRGB = cast(zeros(size(frameWithKTrack(i).cdata)),'uint8');
    for channel = 1:3 
        trackRGB(:,:,channel) = track; 
    end

    %convert the separatedBackFore matrix in a RGB variable
    separatedBackForeRGB = cast(zeros(size(frameWithKTrack(i).cdata)),'uint8');
    for channel = 1:3 
        separatedBackForeRGB(:,:,channel) = ~separatedBackFore(i).cdata; 
    end

    %computes a matrix composed of all zero, but stores the values needed to
    %have white for pixels corresponding to the track
    trackMatrix = trackMatrix.*cast(trackRGB,'uint8').*cast(separatedBackForeRGB,'uint8');

    %adds the track to the current frame
    frameWithKTrack(i).cdata = frameWithKTrack(i).cdata + trackMatrix; 
    colorWaitbar(i/numFrames, barHandler);
end

close(barHandler);

