%**************************************************************************
% Filename   : eraseBackground.m
% Use        : frameWithoutBG = eraseBackground(frame)
% Description: erase the background of a given frame. This function suppose
%              the background to be uniform.
%              input:
%                    - frames: structured frames 
%                              (given by the function aviread).
%              output:
%                    - framesWithoutBG: array of structured frames where
%                      the background is composed by black pixels [0 0 0].
% Authors    : Marco Branca, Lorenzo Camerini
%**************************************************************************

function [framesWithoutBG, barHandler, colourBackGround] = eraseBackground(frames) 

numFrames = length(frames);

barHandler = colorWaitbar(0, 'Erasing-background: please wait...');
%Check the existence of, at least, two frames composing the movie
if numFrames < 2
    disp(['frames must be composed by at least 2 frames in order to' ...
          'find  the background!']);
    return;
end

%separates the foreground from the background by an opening operation on 
%the grayscale image.
g = rgb2gray(frames(1).cdata(:, :, :));
BG = imdilate(g, strel('disk',100)) < max(max(g))/2;

width = size(frames(1).cdata,1);
height = size(frames(1).cdata,2);

BGr = zeros(width,height,3);

for channel = 1:3
    BGr(:,:,channel) = frames(1).cdata(:,:,channel).*cast(BG,'uint8');
end

%finds the background color in flat the bacgkround movie
for i = size(BGr,1)
    for j = size(BGr,2)
        if BGr(i,j,:) ~= zeros(1,1,3);
            bgColor = BGr(i,j,:);
            break;
        end
    end
end

%Creates a movie where the background is black and the subject is white 

for i = 1:numFrames 
    isBackground = frames(i).cdata(:,:,1) ~= bgColor(1,1,1) | frames(i).cdata(:,:,2) ~= bgColor(1,1,2) | frames(i).cdata(:,:,3) ~= bgColor(1,1,3);
    BWBackground(:,:,i) = isBackground;
    framesWithoutBG(i,:,:) = im2frame(cast(BWBackground(:,:,i),'uint8'),[0 0 0;1 1 1]);
    colorWaitbar(i/numFrames,barHandler);
end

colourBackGround = [bgColor(1,1,1) bgColor(1,1,2) bgColor(1,1,3)];